From 7f00b1926f33899b0cbcfed5e4bc9d78594ef9ba Mon Sep 17 00:00:00 2001
From: Janusz Krzysztofik <jkrzyszt@tis.icnet.pl>
Date: Fri, 17 Jun 2011 15:52:51 +0200
Subject: [PATCH] Engine: Prevent from buffer overflows

While using rather long alias names, combined with most options which
output additional information the the Heyu log reported signal
descriptions (like DISPLAY_SENSOR_INTV, ORE_DISPLAY_CHAN, SHOW_CHANGE,
etc.) turned on, it happened to me that my Heyu engine started breaking
regularly, reporting 'buffer overflow', after I rebuilt it with a recent
compiler version.

While this patch can be seen as being far from a proper long-term
solution, and should be rather considered as a simple, non-invasive
preventive workaround, I'm no longer experiencing buffer overflows with
it applied, so decided to push it as a fix.

Signed-off-by: Janusz Krzysztofik <jkrzyszt@tis.icnet.pl>
---
 x10state.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/x10state.c b/x10state.c
index 3f96b84..0593de3 100644
--- a/x10state.c
+++ b/x10state.c
@@ -5870,7 +5870,7 @@ void create_flagslist ( unsigned char vtype, unsigned long vflags, char *flagsli
  +---------------------------------------------------------------------*/
 char *translate_virtual ( unsigned char *buf, int len, unsigned char *sunchanged, int *launchp )
 {
-   static char outbuf[80];
+   static char outbuf[120];
    static char intvstr[32];
    long intv;
    char flagslist[80];
@@ -6326,7 +6326,7 @@ char *translate_gen_longdata ( unsigned char *buff, unsigned char *sunchanged, i
  +---------------------------------------------------------------------*/
 char *translate_sent ( unsigned char *buf, int len, int *launchp )
 { 
-   static char outbuf[80];
+   static char outbuf[120];
    char hc;
    unsigned char hcode, func, level, unit, subunit, chksum;
    unsigned char xgroup, xfunc, xsubfunc, xtype, xdata;
-- 
1.7.3.4

